@@ -7,7 +7,7 @@ import java.util.ArrayList;
 
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.wizardwidget.client.dataresource.ResourceBundle;
-import org.gcube.portlets.user.td.wizardwidget.client.util.ErrorMessageBox;
+import org.gcube.portlets.user.td.wizardwidget.client.util.UtilsGXT3;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.core.client.Callback;
@@ -18,7 +18,7 @@ import com.google.web.bindery.event.shared.SimpleEventBus;
 import com.sencha.gxt.cell.core.client.ButtonCell.IconAlign;
 import com.sencha.gxt.core.client.resources.ThemeStyles;
 import com.sencha.gxt.core.client.util.Margins;
-import com.sencha.gxt.widget.core.client.Dialog;
+import com.sencha.gxt.widget.core.client.Component;
 import com.sencha.gxt.widget.core.client.Window;
 import com.sencha.gxt.widget.core.client.button.TextButton;
 import com.sencha.gxt.widget.core.client.container.BoxLayoutContainer.BoxLayoutData;
@@ -70,6 +70,8 @@ public class WizardWindow extends Window {
 	protected EventBus eventBus;
 	
 	protected ToolBar cardMoveToolBar;
+	
+	protected FillToolItem fillSpacingCardMoveToolBar;
 
 	/**
 	 * Create a new Wizard Window with the specified title.
@@ -113,7 +115,10 @@ public class WizardWindow extends Window {
 		backButton.setEnabled(false);
 		backButton.setTabIndex(1001);
 		cardMoveToolBar.add(backButton,new BoxLayoutData(new Margins(1)));
-		cardMoveToolBar.add(new FillToolItem());
+		
+		fillSpacingCardMoveToolBar=new FillToolItem();
+		
+		cardMoveToolBar.add(fillSpacingCardMoveToolBar);
 
 		nextButton = new TextButton(BUTTONNEXTLABEL);
 		nextButton.setIcon(ResourceBundle.INSTANCE.wizardNext());
@@ -282,7 +287,6 @@ public class WizardWindow extends Window {
 		nextButton.setText(BUTTONFINISHLABEL);
 		nextButton.setIcon(ResourceBundle.INSTANCE.wizardGo());
 		nextButton.setIconAlign(IconAlign.RIGHT);
-		nextButton.getElement().applyStyles("margin-right:2px");
 		nextButtonAction = new Command() {
 
 			public void execute() {
@@ -446,34 +450,46 @@ public class WizardWindow extends Window {
 		return cardStack;
 	}
 
-	public void showErrorAndHide(String title, final String failureReason,
-			final String failureDetails, final Throwable throwable) {
-		ErrorMessageBox.showError(title, failureReason, failureDetails,
-				new Callback<Dialog, Void>() {
+	public void showErrorAndHide(final String title, final String message,
+			final Throwable throwable) {
+		UtilsGXT3.alert(title, message, new Callback<Component,Void>() {
 
-					
-					public void onSuccess(Dialog result) {
-					}
+			@Override
+			public void onFailure(Void reason) {
+				hide();
+				fireFailed(title, message, throwable);
+				
+			}
 
-					public void onFailure(Void reason) {
-						hide();
-						fireFailed(throwable, failureReason, failureDetails);
-					}
-				});
+			@Override
+			public void onSuccess(Component result) {
+				hide();
+				fireAborted();
+				
+			}
+			
+		});
+		
 	}
 
 	public void fireCompleted(TRId id) {
 		for (WizardListener listener : listeners)
 			listener.completed(id);
 	}
-
+	
+	public void firePutInBackground() {
+		for (WizardListener listener : listeners)
+			listener.putInBackground();
+	}
+	
+	
 	public void fireAborted() {
 		for (WizardListener listener : listeners)
 			listener.aborted();
 	}
 
-	public void fireFailed(Throwable throwable, String reason, String details) {
+	public void fireFailed(String title, String message, Throwable throwable) {
 		for (WizardListener listener : listeners)
-			listener.failed(throwable, reason, details);
+			listener.failed(title, message, throwable);
 	}
 }
